/************** BEST VIEWED IN A CODE EDITOR 80 COLUMNS WIDE *******************
*
* Packout Rail Bar Clip
* Benjamen Johnson <3dprints.electronsmith.com>
* 20210301
*
* openSCAD Version: 2019.05 
* Licesnse: Creative Commons - Attribution - Share Alike
*           https://creativecommons.org/licenses/by-sa/4.0/
*******************************************************************************/
/*[Hidden]*/
version="V1.0";

// add a little bit to cuts to make them render properly
$dl = 0.01;

/*[Hole Parameters]*/
/*******************************************************************************
*
*      |----------|<-- counter_diameter
* ----  ---------- ---
*   |   \        /  |
*   |    \      /   | <--counter_depth
* total_  |    |   ---       
* depth   |    |
*   |     |    |
*   |     |    |
* -----    ----
*         |----|<-- hole_dia
*
*******************************************************************************/
// Distance between holes top of bar to bottom
horiz_hole_dist = 25.4;//[0:0.1:50]

// Distance between holes 
vert_hole_dist = 25.4;//[0:0.1:50]

// Diameter of the holes
hole_dia = 5;

// What angle countersink?
countersink_angle = 82; // [60,82,90,100,110,120]

// Depth of the countersink or bore
counter_depth = 2.5;

/*[Bar Parameters]*/
/*******************************************************************************
*
*       -  ---
*      | |  |
*      | |  |
*      | |   bar_width
*      | |  |
*      | |  |
*       -  ---
*       |
*        bar_thickness
*******************************************************************************/
//width of the bar
bar_width = 51.3;

// thickness of the bar
bar_thickness = 3.6;

/*[Clip Parameters]*/
/*******************************************************************************
* the holder is defined by the dimensions of the bar and the wall thickness
*******************************************************************************/
// Wall thickness of the slider
wall_thickness = 4;

// How tall the sliding part of the holder is
clip_width = 50.8;

// Width of the cut in the clip to slip over the bar
slit_thickness = 0.25;

// How much to chamfer the walls of the slit
slit_chamfer = 5;

clip_height = bar_width+2*wall_thickness;
clip_thickness = bar_thickness +2*wall_thickness;

/*[Stamp Options]*/
/*******************************************************************************
* Stamp Options
*******************************************************************************/
// Which font do you want to use
font = "REGISTRATION PLATE UK:style=Bold";

// How big you want the text
font_size = 7;//[0:0.5:8]

// How thick the font is (back to front)
font_thickness = 0.6;

/*******************************************************************************
* Make it
*******************************************************************************/
//translate([0,0,clip_width/2])
difference(){
    make_clip();
    
    translate([-bar_width/2-wall_thickness+font_thickness,0,0])
        rotate([90,-90,-90])
        stamp_version(version, font_size, font_thickness);
}// end difference

/*******************************************************************************
* Module for making the dewalt Toughcase clip
*******************************************************************************/
module make_clip(){
    
CLIP_BODY_DEF=[clip_height,clip_thickness, clip_width]; 
BAR_CUT = [bar_width,bar_thickness, clip_width+$dl];
SLIT_CUT = [wall_thickness*2,slit_thickness,clip_width+$dl];
SLIT_CHAMFER_CUT = [slit_chamfer,slit_chamfer,clip_width+$dl];
    
    difference(){
        cube(CLIP_BODY_DEF,center = true);
    
        cube(BAR_CUT,center=true);
    
        translate([bar_width/2,0,0])    
        cube(SLIT_CUT,center=true);
        
        translate([bar_width/2+wall_thickness,0,0])    
        rotate([0,0,45])
        cube(SLIT_CHAMFER_CUT,center=true);    
        
        //holes
        translate([-vert_hole_dist/2,bar_thickness/2,-horiz_hole_dist/2])
        rotate([90,0,0])
        screw_hole();
          
        translate([vert_hole_dist/2,bar_thickness/2,-horiz_hole_dist/2])
        rotate([90,0,0])
        screw_hole();
        
        translate([-vert_hole_dist/2,bar_thickness/2,horiz_hole_dist/2])
        rotate([90,0,0])
        screw_hole();
          
        translate([vert_hole_dist/2,bar_thickness/2,horiz_hole_dist/2])
        rotate([90,0,0])
        screw_hole();   

        // chamfer the hole for the bar
        chamfer = 1.5;
        scale_x = (bar_width+chamfer)/bar_width;
        scale_y = (bar_thickness+chamfer)/bar_thickness;
        SCALE = [scale_x,scale_y];    
        translate([0,0,clip_width/2-chamfer+$dl])    
        linear_extrude(height = chamfer,convexity=10,scale=SCALE)    
        square([bar_width,bar_thickness],center=true);

        translate([0,0,-clip_width/2+chamfer-$dl])    
        rotate([180,0,0])
        linear_extrude(height = chamfer,convexity=10,scale=SCALE)    
        square([bar_width,bar_thickness],center=true);

    }//end difference
} //end module

/*******************************************************************************
* Module for drilling counterbored or countersuck screw holes
*******************************************************************************/
module screw_hole(){

// Calculate the diameter of the countersink hole
countersink_dia = 2*tan(countersink_angle/2)*(counter_depth)+hole_dia;

    union(){
        translate([0,0,-10])
        cylinder(d=hole_dia,h=20,center=true,$fn=25);
        
        translate([0,0,-counter_depth/2])
        cylinder(d2=countersink_dia,d1=hole_dia,h=counter_depth ,center=true,$fn=25);
        
        translate([0,0,10])
        cylinder(d=countersink_dia,h=20,center=true,$fn=25); 
    }// end union
}

/*******************************************************************************
* Module for putting the version number on the print
*******************************************************************************/
module stamp_version(version_text,size,thickness){
    color("white")
    linear_extrude(height = thickness)
        text(text = version_text, font = font, size = size, valign="center",halign = "center");
} // end module